@@ -9,8 +9,10 @@ from time import sleep, time
 import threading
 import wave
 import struct
+
 import numpy as np
 import pyaudio
+
 from pyffmpeg import FFmpeg
 
 class Audio:
@@ -36,10 +38,10 @@ class Audio:
         self._seek_int = 0
         parent_folder = os.path.dirname(__file__)
         if saveFolder:
-            self.save_folder = saveFolder
+            self.save_folder = os.path.realpath(saveFolder)
         else:
-            self.save_folder = os.path.join(parent_folder,
-                                            'data', 'music', 'saves')
+            self.save_folder = os.path.realpath(
+                os.path.join(parent_folder,'data', 'music', 'saves'))
         if not os.path.exists(self.save_folder):
             os.makedirs(self.save_folder)
         self.ff = FFmpeg(self.save_folder)
